@@ -11,11 +11,11 @@ import requests
 from requests.exceptions import HTTPError, JSONDecodeError
 
 import archimedes
-from archimedes.auth import archimedes_auth, NoneAuth
-from archimedes.configuration import api_config
+from archimedes.auth import get_auth, NoneAuth
+from archimedes.configuration import get_api_config
 from archimedes.data.types import Prediction, PredictionData
 
-API_URL = api_config.url
+API_URL = get_api_config().url
 API_VERSION = 2
 
 
@@ -65,12 +65,12 @@ def get_intraday_trades(
         price_areas = [price_areas]
 
     if start is None:
-        start = archimedes.constants.DATE_LOW
+        start = archimedes.ArchimedesConstants.DATE_LOW
     else:
         start = pd.to_datetime(start)
 
     if end is None:
-        end = archimedes.constants.DATE_HIGH
+        end = archimedes.ArchimedesConstants.DATE_HIGH
     else:
         end = pd.to_datetime(end)
 
@@ -185,12 +185,12 @@ def get(
         price_areas = [price_areas]
 
     if start is None:
-        start = archimedes.constants.DATE_LOW
+        start = archimedes.ArchimedesConstants.DATE_LOW
     else:
         start = pd.to_datetime(start)
 
     if end is None:
-        end = archimedes.constants.DATE_HIGH
+        end = archimedes.ArchimedesConstants.DATE_HIGH
     else:
         end = pd.to_datetime(end)
 
@@ -547,6 +547,7 @@ def get_predictions_ref_dts(prediction_id: str = None, *, access_token: str = No
 
 def _make_api_request(url, method="GET", access_token=None, *args, **kwargs):
     if access_token is None:
+        archimedes_auth = get_auth()
         if archimedes_auth is None:
             raise NoneAuth(
                 "access_token parameter must be passed when using USE_WEB_AUTHENTICATION"
@@ -624,7 +625,7 @@ def store_prediction(
     )
 
     return ret.get("success", False)
-    
+
 
 def store_predictions(
     prediction_id: str,
@@ -652,7 +653,15 @@ def store_predictions(
         True
     """
 
-    predictions = [{"from_dt": p["from_dt"].isoformat(), "ref_dt": p["ref_dt"].isoformat(), "run_dt": p["run_dt"].isoformat(), "data": p["data"]} for p in prediction_data]
+    predictions = [
+        {
+            "from_dt": p["from_dt"].isoformat(),
+            "ref_dt": p["ref_dt"].isoformat(),
+            "run_dt": p["run_dt"].isoformat(),
+            "data": p["data"],
+        }
+        for p in prediction_data
+    ]
 
     payload = {
         "prediction_id": prediction_id,
